import {
  dynamicChainToCrossmintChain
} from "./chunk-6CPZDD6Y.js";
import {
  DynamicContextProviderWrapper
} from "./chunk-RZT2J42J.js";
import {
  useAuthForm,
  useCrossmintAuth
} from "./chunk-LBGALVRW.js";
import {
  __async
} from "./chunk-CRTRMMJ7.js";

// src/providers/auth/web3/DynamicWeb3WalletConnect.tsx
import { EthereumWalletConnectors } from "@dynamic-labs/ethereum";
import { SolanaWalletConnectors } from "@dynamic-labs/solana";
import { jsx } from "react/jsx-runtime";
function DynamicWeb3WalletConnect({
  children,
  apiKeyEnvironment
}) {
  var _a, _b;
  const { crossmintAuth } = useCrossmintAuth();
  const { appearance } = useAuthForm();
  const cssOverrides = `.powered-by-dynamic { display: none !important; } .wallet-list__scroll-container { padding: 0px !important; } .wallet-list__search-container { padding-left: 0px !important; padding-right: 0px !important; } .dynamic-footer { display: none !important; } h1 { color: ${(_a = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _a.textPrimary} !important; } * { color: ${(_b = appearance == null ? void 0 : appearance.colors) == null ? void 0 : _b.textSecondary} !important; }`;
  return /* @__PURE__ */ jsx(
    DynamicContextProviderWrapper,
    {
      apiKeyEnvironment,
      settings: {
        cssOverrides,
        walletConnectors: [EthereumWalletConnectors, SolanaWalletConnectors],
        events: {
          onAuthFlowCancel() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowCancel");
          },
          onAuthFlowClose() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowClose");
          },
          onAuthFailure(data, reason) {
            console.error("[CryptoWalletConnectionHandler] onAuthFailure", data, reason);
          },
          onAuthSuccess(data) {
            console.log("[CryptoWalletConnectionHandler] onAuthSuccess", data);
          }
        },
        handlers: {
          handleConnectedWallet: (wallet) => __async(this, null, function* () {
            var _a2;
            console.log("[CryptoWalletConnectionHandler] handleConnectedWallet", wallet);
            const address = wallet.address;
            if (!address) {
              console.error("[CryptoWalletConnectionHandler] handleConnectedWallet: address is missing");
              return false;
            }
            const chain = yield dynamicChainToCrossmintChain(wallet);
            console.log({ chain });
            try {
              const res = yield crossmintAuth == null ? void 0 : crossmintAuth.signInWithSmartWallet(address);
              const signature = yield (_a2 = wallet.connector) == null ? void 0 : _a2.signMessage(res.challenge);
              const authResponse = yield crossmintAuth == null ? void 0 : crossmintAuth.authenticateSmartWallet(address, signature);
              const oneTimeSecret = authResponse.oneTimeSecret;
              yield crossmintAuth == null ? void 0 : crossmintAuth.handleRefreshAuthMaterial(oneTimeSecret);
            } catch (error) {
              console.error("[CryptoWalletConnectionHandler] Error authenticating wallet:", error);
              return false;
            }
            return true;
          })
        }
      },
      children
    }
  );
}

export {
  DynamicWeb3WalletConnect
};
//# sourceMappingURL=chunk-KPTRUNFA.js.map