import {
  handleSendTransaction
} from "../../../../chunk-A6Q4Z5TO.js";
import {
  dynamicChainToCrossmintChain
} from "../../../../chunk-6CPZDD6Y.js";
import {
  DynamicContextProviderWrapper
} from "../../../../chunk-RZT2J42J.js";
import {
  __async,
  __spreadValues
} from "../../../../chunk-CRTRMMJ7.js";

// src/components/embed/v3/crypto/CryptoWalletConnectionHandler.tsx
import { EthereumWalletConnectors } from "@dynamic-labs/ethereum";
import { DynamicContext, useDynamicContext } from "@dynamic-labs/sdk-react-core";
import { SolanaWalletConnectors } from "@dynamic-labs/solana";
import { useContext, useEffect, useState } from "react";
import { jsx } from "react/jsx-runtime";
function CryptoWalletConnectionHandler(props) {
  const { iframeClient, apiKeyEnvironment } = props;
  return /* @__PURE__ */ jsx(
    DynamicContextProviderWrapper,
    {
      apiKeyEnvironment,
      settings: {
        walletConnectors: [EthereumWalletConnectors, SolanaWalletConnectors],
        events: {
          onAuthFlowCancel() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowCancel");
            iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.failed", {
              error: "cancelled"
            });
          },
          onAuthFlowClose() {
            console.log("[CryptoWalletConnectionHandler] onAuthFlowClose");
          },
          onAuthFailure(data, reason) {
            console.error("[CryptoWalletConnectionHandler] onAuthFailure", data, reason);
          },
          onAuthSuccess(data) {
            console.log("[CryptoWalletConnectionHandler] onAuthSuccess", data);
          }
        },
        handlers: {
          handleConnectedWallet: (wallet) => __async(this, null, function* () {
            var _a;
            console.log("[CryptoWalletConnectionHandler] handleConnectedWallet", wallet);
            const address = wallet.address;
            if (!address) {
              console.error("[CryptoWalletConnectionHandler] handleConnectedWallet: address is missing");
              iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.failed", {
                error: "address is missing"
              });
              return false;
            }
            const chain = yield dynamicChainToCrossmintChain(wallet);
            iframeClient == null ? void 0 : iframeClient.send("crypto:connect-wallet.success", {
              address,
              chain,
              walletProviderKey: (_a = wallet.connector) == null ? void 0 : _a.key
            });
            return true;
          })
        }
      },
      children: /* @__PURE__ */ jsx(_CryptoWalletConnectionHandler, __spreadValues({}, props))
    }
  );
}
function _CryptoWalletConnectionHandler({ iframeClient }) {
  const [showDynamicModal, setShowDynamicModal] = useState(false);
  const { primaryWallet } = useDynamicContext();
  useEffect(() => {
    if (iframeClient == null) {
      return;
    }
    const showAuthFlowListener = iframeClient.on("crypto:connect-wallet.show", ({ show }) => {
      setShowDynamicModal(show);
    });
    return () => {
      iframeClient.off(showAuthFlowListener);
    };
  }, [iframeClient]);
  useEffect(() => {
    if (iframeClient == null) {
      return;
    }
    const signTransactionListener = iframeClient.on(
      "crypto:send-transaction",
      (_0) => __async(this, [_0], function* ({ chain, serializedTransaction }) {
        if (primaryWallet == null) {
          console.error("[CryptoWalletConnectionHandler] signTransaction: primaryWallet is missing");
          iframeClient.send("crypto:send-transaction:failed", {
            error: "primaryWallet is missing"
          });
          return;
        }
        yield handleSendTransaction(
          primaryWallet,
          chain,
          serializedTransaction,
          iframeClient
        );
      })
    );
    return () => {
      iframeClient.off(signTransactionListener);
    };
  }, [iframeClient, primaryWallet]);
  return showDynamicModal ? /* @__PURE__ */ jsx(ShowDynamicModal, { setShowDynamicModal }) : null;
}
function ShowDynamicModal({ setShowDynamicModal }) {
  const context = useContext(DynamicContext);
  if (context == null) {
    throw new Error("DynamicContext is missing");
  }
  const { setShowAuthFlow, handleLogOut } = context;
  useEffect(() => {
    var _a;
    (_a = document.getElementById("crossmint-focus-target")) == null ? void 0 : _a.focus();
    (() => __async(this, null, function* () {
      yield handleLogOut();
      setShowAuthFlow(true, {
        clearErrors: true,
        emitCancelAuth: true,
        ignoreIfIsEmbeddedWidget: true,
        initializeWalletConnect: true,
        performMultiWalletChecks: false
        // Important to be false in order to not require double clicking connect button
      });
      setShowDynamicModal(false);
    }))();
  }, []);
  return null;
}
export {
  CryptoWalletConnectionHandler,
  ShowDynamicModal
};
//# sourceMappingURL=CryptoWalletConnectionHandler.js.map